AP MH     Alignment - Multi reference, rotation   ||   AP MH
                                                              10/8/04

PURPOSE:  Calculates rotational differences between
          experimental images and a series of reference images.  
          Determines the Eulerian angle for rotation needed to 
          align the experimental image with the "most similar" reference
          image.  Mirrored positions are checked.  This operation 
          forms a main part of the 3D Projection Alignment Method 
          The difference between this operation and 'AP MD' lies in this command
          uses only half of the self correlation map to determine the in plane
          rotational angle. (see usage example appended below). '<br>'
          (See '<a href='"'../align_overview.html'"'>'align_overview.html'</a>' 
          for comparison of 'AP' operations.)

SEE ALSO:  VO EA  
           VO MD  
           AP I 
           AP MD  
           AP MI 
           AP MQ 
           AP NQ  
           AP RA  
           AP RD 
           AP RN 

USAGE:    AP MH

          .ENTER TEMPLATE FOR REFERENCE IMAGE SERIES : REF***
          [Give the template name of the existing file series of 2D 
          reference images (typically projections).]

          .ENTER FILE NUMBERS OR SELECTION DOC. FILE NAME: SELECTREF
          [Enter numbers of reference files. The file numbers can also
           be read from a selection document file where file numbers are 
           contained in the first register (not the keys).]

          .FIRST, LAST RING, & SKIP: 5,15,1
          [Only rings with radii in the range 5-15 will be analyzed. 
           If skip=0 or 1, then every ring between 5 and 15 will be taken;
          for skip=2, every second ring; etc.]

          .REFERENCE-RINGS FILE: REF001
          [Give name of reference-rings file. If the file
           exists, SPIDER will read the  reference-rings data from this 
           file and will not read the reference image file series.  If 
           this file does not exist, SPIDER will create/store  the 
           reference-rings data in incore memory. If 
           SPIDER is unable to allocate sufficient memory for the 
           reference-rings data then the reference-rings file must
           exist. In that case, use operation 'AP I' to create 
           the reference-rings file. More than one 
           SPIDER run can use the same reference-rings file. '<br>'
           Note that old responses 'W', 'Y', & 'N' are now obsolete.

          .ENTER TEMPLATE FOR IMAGE SERIES TO BE ALIGNED: DAT***
          [Give the template name of the existing file series of 
          experimental images.  These images will be checked for 
          alignment versus the reference images.]

          .ENTER FILE NUMBERS OR SELECTION DOC. FILE NAME:1-21
          [Enter numbers of experimental files. The file numbers can
          also
           be read from a selection document file where file numbers are
          contained in the
           first register (not the keys).]

          .OUTPUT ANGLES DOCUMENT FILE: APMH101
          [This is the only output produced by this program.
           It contains 6 columns as follows: '<br>'

            1. Number of the most similar reference image.'<br>'
               When this number is negative, the most similar image 
               is the mirrored image (see note 1).               '<br>'

            2. Not-normalized correlation coefficient.          '<br>'
               Can be used as a similarity measure.             '<br>'

            3. "-psi" angle.                                    '<br>'
              In-plane rotation angle determined.  To use in 3D
              reconstruction programs invert the sign.

            4. Always 0.0                                       '<br>'

            5. Always 0.0                                       '<br>'

            6. Current experimental image number.               '<br>'

            7. Always -1.0.]                                    '<br>'


 NOTE:   1. In 3D space the projection with the direction: (psi, theta, phi)
            has its mirrored (around X-axis) counterpart in the
            direction:'<BR>'
                       (-psi, 180-theta, phi+180).'<BR>'
            To save time, the program takes this into account, and each data
            projection is compared with the reference projection and its
            mirrored version at the same time.  Thus, only half of the  total 
            number of reference projections are required; namely, only those
            with 0<theta<90.
            If the best match was with the mirrored reference projection,
            then the number stored in the first column of the document file
            is negative (see included batch program).

        2. Images need not have power-of-two dimensions.

        3. The reference projections (of the existing structure)
           can be created using 'VO EA' and 'PJ 3Q' commands.  'VO EA'
           creates an angular document file with quasi-evenly spaced
           projection directions and 'PJ 3Q' creates projections
           of the volume according to this doc file.

        4. The output document file created by 'AP MH' can be converted
           to the angular document file using 'VO MD' command.  Please
           note that in this case the angular document file created
           by 'VO EA' is required.

        5. The operation switches automatically between in-core and on-disk
           versions depending on the memory available.  The  reference
           rings file can be used in either case.

        6. Columns number 4 and 5 in the output document files
           are always filled with zeros and 
           correspond to zero translation.  This is done to keep the
           the document file format the same as in 'AP MD' command. 

        7. The operation is computationally intensive. The code is
           parallel.

        8. An example of the Spider batch program which can be used to
           produce an angular document file from the output document file of
           this command is included in the manual chapter for the command
           'VO MD'.

        9. Implemented by Paul Penczek

 SUBROUTINE: APMASTER, APRINGS, DSGR_PM, DSFS_P, NORMAS, ALRQS, ALPRBS, 
            CROSRNG_MS, FRNGS, PRB1D, FFTR_D, FFTC_D, APPLYW

 CALLER:     UTIL4


 The following example demonstrates how to apply parameters found 
 (in-plane rotation and mirror operation) to the input images:

 ; x91 - number of images
 x91=500
 DO LB1 x21=1,x91
   x21=x0
   UD IC,x21,x51,x52,x53,x61,x61,x81
   apmh500
   x53=-x53
   ;
   IF(x51.LT.0) THEN
      MR
      avs{***x81}
      _1
      Y
      RT SQ
      _1
      avt{***x81}
      x53
      (0,0)
      x51=-x51
      x53=x53+180
      GOTO LB2
   ENDIF

   IF(x51.GT.0) THEN
      RT SQ
      avs{***x81}
      avt{***x81}
      -x53
      (0,0)
   ENDIF

   LB2

   SD x21,x51,x52,x53
   apmhcnv

 LB1
 
 SD E
 apmdcnv

 EN
