AP RN     Alignment - multi-reference, restricted projections, no mirror check ||  AP RN
                                                               1/28/04

PURPOSE:  Compares a set of experimental images with a set of reference images.
          For each experimental image, it finds the in-plane Euler rotation which
          aligns the experimental image with the most-similar reference image.
	  An experimental image is only compared with reference images  within 
          a restricted angular range. Mirrored positions  are NOT checked.  
          The only difference between this
          operation and 'AP RD' is how they handle mirroring.
           '<br>'(See '<a href='"'../align_overview.html'"'>'align_overview.html'</a>' 
            for comparison of 'AP' operations.)

SEE ALSO:  VO EA  
           VO MD  
           AP I 
           AP MD  
           AP MQ 
           AP NQ 
           AP RA 
           AP RD 
           AP REF 

USAGE:    AP RN
           <or>   '<br>'    
          AP RN X10,X11,X12,X13,X14,X15,X16

          .ENTER TEMPLATE FOR REFERENCE IMAGE SERIES: REF***
          [Give the template name of the existing file series of 
           reference images (typically projections).]

          .ENTER FILE NUMBERS OR SELECTION DOC. FILE NAME: SELECTREF
          [Enter numbers of reference files. The file numbers can also
           be read from a selection document file where file numbers are contained in the
           first register (not the keys).]

          .FIRST, LAST RING & SKIP: 5,15,1
          [Only rings with radii in the range 5-15 will be analyzed. 
           If skip=0 or 1, then every ring between 5 and 15 will be taken;
          for skip=2, every second ring; etc.]

         .REFERENCE IMAGE ANGLES DOCUMENT FILE: REFANGLES
          [Enter the name of the angular document file containing Eulerian
           angles of reference images (projections): psi, theta, phi.]

          .REFERENCE-RINGS FILE: REF001
          [Give name of reference-rings file. If the file
           exists, SPIDER will read the  reference-rings data from this 
           file and will not read the reference image file series.  If 
           this file does not exist, SPIDER will create/store  the 
           reference-rings data in incore memory. If 
           SPIDER is unable to allocate sufficient memory for the 
           reference-rings data then the reference-rings file must
           exist. In that case, use operation 'AP I' to create 
           the reference-rings file. More than one 
           SPIDER run can use the same reference-rings file.             '<br>'
           Note that old responses 'W', 'Y', & 'N' are now obsolete.

     
          .ENTER TEMPLATE FOR IMAGE SERIES TO BE ALIGNED: DAT***
          [Give the template name of the existing file series of 
          experimental images.  These images will be checked for 
          alignment versus the reference images.]

          .ENTER FILE NUMBERS OR SELECTION DOC. FILE NAME:1-21
          [Enter numbers of experimental image files. The file numbers can also
           be read from a selection document file where file numbers are contained in the
           first register (not the keys).]

          .EXPERIMENTAL IMAGES ANGLES DOCUMENT FILE: angles001
          [Enter the name of the angular document file containing Eulerian
           angles of experimental images (projections: psi, theta, phi.
           Experimental images will be compared with only these
           reference images whose normal is within a specified range from
           this angular value.]

          .RANGE OF ANGULAR SEARCH FOR PROJECTIONS: 20.0
          [Experimental images will be compared with only these
           reference images whose normal is within 20 degrees range.]

       If registers were specified on the operation line then
       no output document file is created.  Instead the registers
       receive the output that normally would be put into the
       document file. This is useful when only a single image is 
       being aligned.

          .OUTPUT ANGLES DOCUMENT FILE: APMD101
          [This is the only output produced by this program.
           It contains 7 register columns:                 '<br>'

            1. Number of the most similar reference projection.'<br>'
               When no matching projection was found within
               the angular range specified, this column will contain 0.'<br>'

            2. Not-normalized correlation coefficient.          '<br>'
               Can be used as a similarity measure.             '<br>'

            3. "-psi" angle.                                       '<br>'
              In-plane rotation angle determined.  To use in 3D
              reconstruction programs invert the sign.

            4. Always 0.0                                       '<br>'

            5. Always 0.0                                       '<br>'

            6. Experimental image number.                       '<br>'

            7. Angular change for projection.]           '<br>'

NOTE:   1. The reference projections (of the existing structure)
           can be created using 'VO EA' and 'PJ 3Q' operations.  'VO EA'
           creates an angular document file with quasi-evenly spaced
           projection directions and 'PJ 3Q' creates projections
           of the volume according to this doc file.

        2. The output document file created by 'AP MD' can be converted
           to the angular document file using 'VO MD' operation.  Please
           note that in this case the angular document file created
           by 'VO EA' is required.

        3. The operation switches automatically between in-core and on-disk
           versions depending on the memory available.  The scratch.file
           is created/required in either case.

        4. The operation switches automatically between in-core and on-disk
           versions depending on the memory available.  The  reference
           rings file can be used in either case.

        5. The operation is computationally intensive. The code is
           parallel.

        6. An example of the SPIDER batch program which can be used to produce
           an angular document file from the output document file of this
           operation is included in the manual chapter for the operation 'VO MD'.

        7. Implemented by: Paul Penczek

SUBROUTINE: APMASTER, APRINGS, DSGR_PM, DSFS_P, NORMAS, ALRQS, ALPRBS, 
            CROSRNG_MS, FRNGS, PRB1D, FFTR_D, FFTC_D, APPLYW

CALLER:     UTIL4


The following example procedure demonstrates how to apply parameters found 
(in-plane rotation) to the input images:

; x91 - number of images
x91=500
DO LB1 x21=1,x91
   UD IC,x21,x51,x52,x53,x61,x61,x81
   apmd500
   IF(x51.EQ.0) THEN
      CP
      avs{***x81}
      avt{***x81}
   ELSE
      RT SQ
      avs{***x81}
      avt{***x81}
      x53
      (0,0)
      SD x21,x51,x52,x53
      apmdcnv
   ENDIF
LB1 
SD E
apmdcnv
EN
