
BP RP     Back Projection - 3D, iterative, with constraints, ||   BP RP   
                                                               02/12/01

PURPOSE:  Calculates 3D reconstruction using constraints.

SEE ALSO: BP 3F   (3D reconstruction using interpolation in Fourier space.)
          BP 32F  (3D reconstruction using interpolation in Fourier space.)
          BP 3D   (Back Projection - 3D, using Euler angles, ||)
          BP CG   (Back Projection - 3D, conjugate gradients, ||)
          BP MEM2 (Back Projection - 2D maximum entropy method)
          BP R2   (Back Projection - 2D, R**2 weighting of the image series)
          BP S2   (Back Projection - 2D, single tilt iterative, with constraints)
          BP W2   (Back Projection - 2D, filtered weighted)

USAGE:    BP RP
           <OR> '<BR>'
          BP RP,X11'<BR>'

          .ENTER TEMPLATE FOR 2-D IMAGE FILE: PROJ***
          [Enter template for projection input files.]

          .ENTER FILE NUMBERS OR SELECTION DOC. FILE NAME: 1-700 OR IMAGES127
          [Enter projection file numbers or the name of the document file 
           containing projection file numbers in the first column.]

          .RADIUS OF RESTORED OBJECT: 23
          [Enter radius of reconstructed object (smaller than the
           volume size). The reconstruction is calculated inside the
           sphere only.]

          .ANGLES DOC FILE: ANGLES27
          [Enter the name of the document file containing Eulerian
           angles for the projections used (psi, theta, phi).]

	  .SYMMETRIES ANGLES DOC FILE: ANGSYM
           [Enter '<B>'*'</B>' if the structure has no symmetries.'<BR>'
           Otherwise, enter the name of the document file containing
           Eulerian angles defining symmetries (psi, theta, phi). The
           angles should be such that when used in operation 'RT 3D'
           they transform the volume into itself.  The identity
           operation (angles 0,0,0) MUST be included.  The symmetries
           will be internally enforced on the volume.  The
           reconstruction in this case is calculated as though the
           projections were multiplied as many times as there are
           symmetries.]

	  .RECONSTRUCTED 3-D FILE: VOLUME1001
           [Name of the output file.]

          .LAMBDA, CORRECTION LIMIT: 1.0e-4,0.0
          ['<B>'Lambda'</B>' determines the weight of corrections. Too small a
           value results in long time of calculations; too large
           value will terminate the iterations too soon. (Note #3). '<BR>'
           '<B>'Correction limit'</B>' can be used to terminate the iterations.
           When the squared correction of the structure becomes
           smaller than the preset value, the iterations are
           terminated.  When correction limit is set to zero,
           it will not be used to terminate the program.  Iteration limit will
           be used instead.] 

          .ITERATION LIMIT, MODE: 25,8
          [Program will terminate after number of iterations given. '<BR>'
           Mode determines the constraints used:              '<BR>'
           0 - no constraints,                                '<BR>'
           1 - frequency limit (smoothing),                   '<BR>'
           2 - min constraint,                                '<BR>'
           5 - max constraint.                                '<BR>'
           Any combination of constraints can be used. The mode value
           should be the sum of any single modes, for example mode=7
           activates both min and max constraints, while mode=8 uses all three of 
           them. Constraints are ignored if mode=0, but dummy values should
           still be entered on the next two lines.]

          .MINIMUM, MAXIMUM: 1.77,1.90
          [Values of min and max constraints: i.e., the max and min values of
           the 2D projection data set.]

          .SMOOTHING CONST (0-0.999):0.9994
          [Smoothing constant determines relative weight of the low-pass
           filtration. See note #4.]

NOTES:    1. The projections need not have power-of-2 dimensions.

          2. If the radius of the reconstructed circle is too large
             comparing to the size of projections, a warning is printed.
             The reconstruction is calculated, but it is incorrect
             along the boundary.

          3. Lambda is used to control the speed of convergence.'<BR>'
             Too small value of lambda will result in a structure
             that has high frequencies underrepresented.  The structure
             will appear very smooth.  Moreover, when such structures are
             used to estimate the resolution (command RF 3) the Fourier
             Shell Correlation curve, after initial decrese, will increase
             in high frequencies region.  To remedy the problem, the
             lambda has to be increased (10 times).'<BR>'
             Too large value of lambda will terminate iterations too
             soon, earlier than requested number of iterations,
             usually after first two or three steps.  This can be verified
             in the output stored in the results file.  '<b>'Resulting 
             structure will be incorrect.'</b>'  To remedy this problem
             the lambda has to be decreased (2 times) and the program
             has to be repeated.  If the problem persists, the lambda
             has be decreased again until the requested number of
             iterations is performed.

          4. Smoothing constant determines relative weight of the 
             low-pass filtration.
             It has to be larger than zero and smaller than one.
             In addition smoothing constant has to be lower than
                1/(1+6*lambda).                

             Zero means no smoothing.                             '<BR>'

             To achieve stronger low-pass filtration effect one can 
             decrease lambda and increase the smoothing constant. '<BR>'

             Approximate frequency response:

           '<PRE>'
             lambda     smoothing const    res'n limit (pixels)
              .5E-3         0.990                 3
              .5E-3         0.997                 5
              .1E-3         0.9994               10
           '</PRE>'

          5. It is assumed that projections are squares (NSAM=NROW), so
             the output volume has dimensions NSAM x NSAM x NSAM.

          6. Memory requirement: 2*(NSAM**3)

          7. An optional register on the OPERATION line receives
            the number of iterations completed.

          8. Implemented by: Paul Penczek.

SUBROUTINES: REPS, REDPRQ, RPRQ, ASTA, PREPCUB_S, BCKCQ, PRJCQ, 
             SMT3_Q, DOMIN3_S, DOMAX3_S, DOCORS3_S, BMAX_C, BMIN_C,
             FMAX_Q, FMIN_Q, HIANG

CALLER:      VTIL2
