
CC H      Cross Correlation, Phase ||                           CC H      
                                                            03/18/02

PURPOSE:  Computes the phase cross-correlation function of two
          images/volumes using the Fourier transform relationship. 
          The dimensions of the two images/volumes must be the same.
          See 'FT' for Size restrictions.

SEE ALSO:  CC
           CC N   (Cross Correlation - Normalized)
           CN     (CoNvolution)
           CN N   (CoNvolution - Normalized)
           AC     (Auto Correlation)
           AC N   (Auto Correlation - Normalized)
           CC C   (Cross Correlation Coefficient)
           FT     (Fourier Transform)

USAGE:    CC H

          .INPUT FILE: PIC001
          [Enter the name of the first image/volume.]

          .REFERENCE FILE: REF001
          [Enter the name of the second image/volume, which is used
          as the reference.]

          .OUTPUT FILE: CCF001
          [Enter name for  file which will contain phase cross-correlation
          coefficients. It can be the same as the input file.  In this case
          INPUT FILE will be replaced by the cross correlation.]

NOTES: 1. The input data can be real or Fourier in any 
          mixed form.

       2. The cross-correlation data are not scaled.  (If values are
          very, very large then maybe you should reduce the FMAX
          of the input files first?)

       3. The origin of the CCF is at (NSAM/2 + 1, NROW/2 + 1).

       4. The CCF contains artifacts from wraparound overlaps
          implicit in the Fourier computation.
          However, the CCF is artifact-free within                     '<BR>'
                -L <= K <= +L   '<br>'                                       '<BR>'
                -M <= I <= +M   '<br>'                                   '<BR>'
          if the images are surrounded by frames containing
          the average, where the frame width is M/2 and the
          frame height is L/2.  This can be achieved by use of
          the 'PD' operation. '<br>'
          The complete artifact-free CCF is obtained for the
          widths M=NROW/2, L=NSAM/2.  In this case, the padded
          pictures are just twice as large in each dimension as
          the original pictures.


       5. If the data cannot fit into the memory, use the 'FT' and 'MU'
          commands to calculate the CCF e.g.:
          '<PRE>'
              FT
              INPUT1
              FOUR1
              FT
              INPUT2
              FOUR2
              MU M
              FOUR1
              FOUR2
              FT
              FOUR2
              CCF12
        '</PRE>'
        '<STRONG>'WARNING'</STRONG>': The origin of CCF12 calculated in this 
         way is in (1,1).

       6. The phase correlation is calculated as follows in FORTRAN: 
        '<PRE>'
         CTEMP  = X(I,J)*CONJG(Y(I,J))*CMPLX(COS(ARG),SIN(ARG))'<br>'
         O(I,J) = CTEMP / (SQRT(REAL(CTEMP)**2 + AIMAG(CTEMP)**2))'<br>'
        '</PRE>'
            
SUBROUTINES: FMRS_2, FMRS_2R, FFTMCF, FMRS_1, FMRS_3, FMRS_3R,
             CCRS_2, CCRD_2, CCRS_3, CCRD_3

CALLER:      CORR1
