RF 3       Phase Residual & Fourier shell correlation, 3D  ||      RF 3
                                                               08/15/05

PURPOSE:   Calculate the differential 3-D phase residual and the Fourier  
           Shell Correlation between two volumes. The Differential  
           Phase Residual over a shell with thickness given by shell
           width and the Fourier Shell Correlation between shells of 
           specified widths are computed and stored in the document 
           file.  Does not need powers of two dimensions (for exclusions 
           see 'FT' operation) and  takes real or Fourier input volumes.  
           NSAM, NROW and NSLICE need to be the same in both volumes. 


SEE ALSO:  RF    (R Factor)
           RF SN (Spectral signal to noise ratio)
           FT    (Fourier transform)

USAGE:     RF 3
           <or>   '<br>'
           RF 3 x11,x12

          .FIRST INPUT FILE: SUB001
          [Enter the name of the first input volume. File can be real
           or Fourier. ]

          .SECOND INPUT FILE: SUB002
          [Enter the name of the second input volume. File must be of
           same type and dimensions as first input file.]

          .RING WIDTH: 1.
           [Enter the shell thickness in reciprocal space sampling units.] 

          .SCALE FACTOR (LOWER,UPPER): 0.6,1.2
           [Give the range of scale factors by which the second Fourier must be 
           multiplied for the comparison.] 

          .MISSING CONE/WEDGE ANGLE (C/W): C
           [Use 'C' if you have a missing cone and 'W' if you have a 
           missing wedge. 

          .MAXIMUM TILT ANGLE: 30
           [Give the angle of maximum tilt angle in degrees. (When the 
            missing cone is covered angle = 90.0)] 
	
          .FACTOR FOR NOISE COMPARISON: 3.0
           [The factor given here determines the FSCCRIT. Here 3.0 
           corresponds to 
           the 3 sigma criterion i.e., 3/SQRT(N), where N is number of 
           voxels for a given shell.  You could use 2, 1,4 or anything.]

          .DOCUMENT FILE: DOC001
           [Enter name of doc. file in which results are to be saved.] 

NOTES:     1.  The inclination angle theta starts from the Z*=0 plane. 

           2.  Scale search is done separately for each shell. This will NOT lead 
           to sensible results if one of the transforms falls off rapidly in a 
           frequency range where the other transform is strong.  The range specified 
           by the user is divided into 20 steps and searched for the lowest
           value The value: '<BR>'
           R(McPherson) = 2*SUM(ABS(F1)-ABS(F2))/SUM(ABS(F1)+ABS(F2))   '<BR>'
           is calculated at each step within a ring and its minimum is used to 
           determine the correct scale factor for the second Fourier transform. 

           3. The 'NO SOLUTION' warning message relates to DPR normalization 
           factor between two volumes, which is searched using a brute 
           force method.  This message is NOT relevant to FRC results.

	   4. The "LACKS MINIMUM" warning pertains to the DPR only.  If
	   you do not use DPR, you can ignore it. '<br>'

	   If you use DPR, you should be aware that DPR, unlike FSC,
	   depends on the relative multiplicative scaling of two
	   Fourier transforms .  Simply speaking, FSC is a correlation
	   coefficient, so it does not depend of either F or G being
	   multiplied by anything.  At the same time, DPR contains sums
	   of |F| and |G|, so the result will depend on s, as in
	   |F|+s|G|.  Thus, the proper definition of DPR should state
	   that it is a minimum over s, the fact rarely brought up. The
	   range of s has to be specified by the user and one is
	   prompted for it.  If there is no minimum within the range
	   specified, the warning will appear.  If the two structures
	   compared originated from the same data set, the minimum
	   should be found somewhere between 0.2,2.  If it does not, it
	   is likely that one of the structures is wrong.  If, on the
	   other hand, 'RF 3' is used to calculate cross-resolution,
	   i.e., to compare EM and X structures, the warning will
	   appear almost always, as two structures are usually in
	   completely different scales.

           5.  COMMENTS and REFERENCES with regard to FSC 
           Ref: Saxton and Baumeister, '<I>'J.of.Micr.'</I>', 127,(1982) 127-138. 
           M. van Heel, '<I>'Ultramicroscopy'</I>'., 21, (1987) 95-100. 
           Unser,et.al.,  '<I>'Ultramicroscopy'</I>', 23, (1987) 39-52. 
           A correlation coefficient "r" implies a SNR=2*r/(1-r). (factor
           2 comes from the fact that for the purpose of comparison whole data set is 
           divided into halves). SNR=4.0 implies r=0.67 SNR=2.0 implies r=0.5 WHY 
           these two special cases of SNR? According to Unser FSC=0.67 should 
           correspond to DPH=45. 

           6) If registers were specified on the operation line then
           the first register receives the interpolated frequency (pixel) at
           when FSC falls below a value of 0.5, and 
           the second register receives the interpolated spatial frequency at 
           this point.  If there are multiple downward crossings of the
           FSC cutoff line then the values are reported for the last crossing.
           If there is no such crossing then the last values from the doc.
           file output are reported. 

           7.  The following measures are computed: 
      
   '<pre>'
 a) PHASE RESIDUAL =  
      SQRT(SUM[(ABS(F1)+ABS(F2))*DPHI**2]/ SUM(ABS(F1)+ABS(F2))) 
      where DPHI = The phase difference between corresponding Fourier,
      coefficients which should be < 45 DEG. 

 b) SHELL CORRELATION = 
      [SUM(F1*CONJ(F2))]/ [SQRT{SUM(ABS(F1)**2)*SUM(ABS(F2)**2)}] 
      where CONJ implies complex conjugate.
                                                                        
   '</pre>'

          8.  Contents of DOC and RESULTS file:                                       
   '<pre>'
   COLUMN:       #1          #2      #3        #4          #5  
  |NUMBER|   |NORMALIZED    |DPH|   |FSC|   |FSCCRIT|    |VOXELS|
             |FREQUENCY|
   '</pre>'

SUBROUTINES:  PR3D, PR3DB, RFACTSD2, FMRS_3

CALLER:       FOUR1 

