
TF C      Transfer Function - Complex                      TF C
                                                            10/23/96

PURPOSE:  To compute the phase contrast transfer function for
          bright-field electron microscopy. The 'TF C' operation
          produces the transfer function in complex form so that
          it can be applied (by using 'MU') to the Fourier transform
          of a model object, for simulations of bright-field weak
          phase contrast. For literature, see Notes.

SEE ALSO: TF      (Transfer Function - defocus dependent)
          TF C3   (Transfer Function - complex 3D)
          TF CT   (Transfer Function - phase flipping, complex, ternary)
          TF CT3  (Transfer Function - complex, ternary 3D)
          TF CTS  (Transfer Function - CTF correction)
          TF D    (Transfer Function - display)
          TF DDF  (Transfer Function - determine defocus and amplitude contrast)
          TF DEV  (Transfer Function - determine envelope function)
          TF DNS  (Transfer Function - determine and delete noise background)
  
USAGE:    TF C

          .OUTPUT FILE: TFC001
          [Enter the name of the output file that will store the computed
          function.]

          .CS [MM]: 2.0
          [Enter the spherical aberration constant.]

          .DEFOCUS(A), LAMBDA(A): 2000,0.037
          [Enter the amount of defocus, in Angstroems.  Positive 
          values correspond to underfocus (the preferred region);
          negative values correspond to overfocus. Next, enter
          the wavelength of the electrons.  The value used in
          this example corresponds to 100kV. 
          A table of values is listed in the glossary under 
          '<a href='"'../glossary.html#Lambda'"'>'lambda'</a>'.]

          .DIMENSIONS OF OUTPUT ARRAY: 128, 128
          [Enter the dimensions of the (real) 2D array, whose Fourier transform
          you plan to multiply by the complex output of TF C.]

          .MAXIMUM SPATIAL FREQUENCY [1/A]: 0.15
          [Enter the spatial frequency limit in 1/Angstroem units.
          The maximum spatial frequency is 1/(2*pixelsize), where
          pixelsize is the size of the pixel in Angstroems.] 

          .SOURCE SIZE[1/A], DEFOCUS SPREAD[A]: 0.005,250
          [Enter the size of the illumination source in reciprocal
          Angstroems. This is the size of the source as it appears in
          the back focal plane of the objective lens.  A small value
          results in high coherence; a large value, low coherence.
          Enter the estimated magnitude of the defocus variations  
          corresponding to energy spread and lens current fluctuations.]

          .ASTIGMATISM[A], AZIMUTH[DEG]: 400,30
          [Enter the defocus range due to axial astigmatism.
          The value given indicates a defocus range of +/- 400A around
          the nominal value as the azimuth is varied. Then,
          enter the angle, in degrees, that characterizes the  
          direction of astigmatism.  The angle defines the origin 
          direction where the astigmatism has no effect.]

          .AMPLITUDE CONTRAST RATIO [0-1], GAUSSIAN ENVELOPE HALFWIDTH[1/A]:                    0.1,0.15
          [Enter ACR and GEH. The envelope parameter specifies
          the 2 sigma level of the Gaussian (see note 2 for details).]

          .Sign (+1 or -1): -1
          [Application of the transfer function results in contrast
          reversal if underfocus (DZ positive) is used.  To compensate for
          this reversal, use sign switch -1.]
         
          The transfer function is then computed in complex form compatible 
          with the Fourier transform format.

NOTES: 1. Theory and all definitions of electron optical parameters
          are as in: J. Frank (1973)'<I>' Optik'</I>' 38:519, and R. Wade
          & J. Frank (1974) '<I>'Optik'</I>' 49:81.  Internally, the program
          uses the generalized coordinates defined in these papers.

       2. In addition, an optional cosine term has been added with a weight,
          and an ad hoc Gaussian fall off function has been added as discussed
          in Stewart et al., '<I>'EMBO J.'</I>' 12 (1993) 2589-2599.

          The complete expression is:                                    '<BR>'

          TF(K) = [(1-ACR)*sin(GAMMA) - ACR*cos(GAMMA)]*ENV(K)*exp[-(K/GEH)^2
          '<BR>'
          In an array of size N, the halfsize H = (N/2)+1. Each 
          element of the array (K) corresponds to a spatial
          frequency                                                   '<BR>'
                  Kx = (K-H) * DK                                    '<BR>'
          where DK is the maximum spatial frequency.]

     3. To apply the transfer function to a model 2D structure, use the 
        following steps:                                                 '<BR>'
            (i)   use 'FT' to compute the Fourier transform of the model 
        structure,                                                       '<BR>'
            (ii)  use 'TF C' to compute the transfer function in complex 
        format,                                                          '<BR>'
            (iii) use 'MU' to multiply the Fourier transform with the 
        complex transfer function,                                       '<BR>'
            (iv)  use 'FT' to compute the inverse Fourier transform.
           
SUBROUTINES: TRAFC, TFD

CALLER:      UTIL1 

