
TF DDF      Transfer Function - Determine DeFocus & amplitude contrast   TF DDF    
					                     11/28/00

PURPOSE:   Calculate the defocus and amplitude contrast ratio from minima 
           of 1D profile of contrast transfer function. Input can be single 
           image or a series of images.

SEE ALSO: TF      (Transfer Function - defocus dependent)
          TF C    (Transfer Function - complex)
          TF C3   (Transfer Function - complex 3D)
          TF CT   (Transfer Function - phase flipping, complex, ternary)
          TF CT3  (Transfer Function - complex, ternary 3D)
          TF CTS  (Transfer Function - CTF correction)
          TF D    (Transfer Function - display)
          TF DEV  (Transfer Function - determine envelope function)
          TF DNS  (Transfer Function - determine and delete noise background)

USAGE:    TF DDF

          .HOW MANY IMAGES IN THE SERIES: 1
          [Enter number of images. If you want to process a series images, 
          input images in either increasing or decreasing sequence.]

          .IMAGE FILE: ro008
          [Enter file name of 1D profile of power spectrum.]

          .MAXIMUM SP. FREQ [A-1]: 0.171
          [Enter the spatial frequency limit in 1/Angstroem units. The maximum 
          spatial frequency is 1/(2*pixel).]

          .SEARCH NEIGHBOUR AREA [POINT]: 5
          [This parameter controls the size of the local neighborhood that is 
          searched for local minima. For each point in the spectrum, N points
          on either side are searched (total neighborhood = 2N + 1 pixels).]

    At this point, minima are located and printed out. The first column contains
    the keys, the second column is the location of each minimum (value is interpolated
    between pixels), the third column has the same location in spatial frequency
    units. The last column represents the amplitude of the minimum.
         '<PRE>'
          IMAGE HAS FOLLOWING MINIMA
          # 1,  28.0416489,  1.914100535E-2 (A-1)   A = 3.936556168E-4
          # 2,  58.7729225,  4.01179269E-2 (A-1)    A = 2.553723752E-4
          # 3,  83.1436234,  5.675316975E-2 (A-1)   A = 2.277945168E-4
         '</PRE>'

          .CHANGE SEARCHING NEIGHBOUR (Y/N): n
          [ If "Y", the above operation will be repeated. Smaller search areas may
          identify noise as minima, resulting in spurious minima. Large search areas
          can smooth out and overlook actual minima if they are too small. Increase
          the search neighborhood if your data is very noisy; decrease it if you have
          many small minima.]

          .HOW MANY POINTS DO YOU WANT?: 3
          [Enter the number of minima you want to include in the calculation.]

          POINT # 1
          .SP. FREQ. POINTS/ ABERRATION (PI): 28.0, -1
          [Enter the grid point of the minimum, which is found in the second 
          column in the list of minima found by the program, and its 
          corresponding aberration value in units of pi. For underfocus, the
          first minimum is -1, the second is -2, the next is -3, and so on.
          For overfocus, the first minimum is zero, the second is 1, the next
          is 2, and so on.]

          POINT # 2
          .SP. FREQ. POINTS/ ABERRATION (PI): 58.8, -2

          POINT # 3
          .SP. FREQ. POINTS/ ABERRATION (PI): 83.1, -3

       If a defocus series is used, the following question will appear:
		
          .CONSTRAINTS: (1), (2) or (3): 1
          [Enter the choice of constraints, as follows:    '<BR>'              '<BR>'
                (1) same amplitude,            '<BR>'                           '<BR>'
                (2) same amplitude and define defocus interval, '<BR>'          '<BR>'
                (3) same defocus.                  '<BR>'                        ]

          .LAMBDA(ANGSTROEMS): 0.037
          [Enter the wavelength of the electrons.  The value used in
          this example corresponds to 100kV.
          A table of values is listed in the glossary under 
          '<a href='"'../glossary.html#Lambda'"'>'lambda'</a>'.]

          .SPHERICAL ABERRATION CS [MM]: 2.0
          [Enter the spherical aberration coefficient, in mm.]

    At this point, values are calculated and printed out:
         '<PRE>'
          DEFOCUS= 24278.6875 (Angstroms)
          AMPLITUDE CONTRAST=  0.143490 
         '</PRE>'

          .DO YOU WANT TO GENERATE A FILTER? (Y/N)  : y
          [This option can generate a 1D filter file which is used by 
          FD to correct the CTF.]

    If you answer "Y", the following question appears:

          .OUTPUT FILE: fil008
          [Enter the name for the filter file. The filter files are 
          generated in the same sequence as the input files if you 
          process a series.]


NOTES: 1. The outline of the theory is as for TF. See Zhu et al. (1997)
          '<I>' Journal of Structural Biology'</I>', 118, 197-219.

       2. The amplitude contrast ratio is calculated by a grid search method, 
          and low spatial frequecy minima are treated with a special weighting 
          for amplitude contrast.

       3. The method to prepare a 1D profile is described in J. Zhu and J.
          Frank (1994) In, '<I>'Electron Microscopy 1994 (Proceedings of the 13th
          Intl. Congr. on Electr. Microsc. (Paris))'</I>', pp.465-6. The procedure 
          is given below:

     '<PRE>'
        ;.........................................................
        fr
        ?image file ?                 ;input image <p1>
        FR
        ?power spectrum file ?        ;output power spectrum <p2>
        X21=0
        X42=200
        DO LB1 X80=1,12               ;NUMBER OF PIECES HORIZONTAL DIRECTION
        X41=120
        DO LB2 X81=1,12		      ;NUMBER OF PIECES IN VERTICAL DIRECTION
        WI			      ;get small pieces of the input image
        <1>
        _1
        (512,512)                     ;size of small pieces
        X41,X42
        RA			      ;CORRECT RAMP EFFECTS
        _1
        _2
        X21=X21+1
        PW			      ;CALC POWER SPECTRUM OF EACH SMALL PIECE
        _2			      ;CALC SQUARE ROOT OF POWER SPECTRUM
        _3
        SQ			      ;CALCULATE REAL POWER SPECTRUM
        _3			      
        pwa{****x21}
        WI			      ;window central section of quick checking
        pwa{****x21}
        pwb{****x21}
        (80,80)
        (217,217)
        X41=X41+256		      ;50% OVERLAPPING WITH ITS NEIGHBOURS
        LB2
        X42=X42+256
        LB1
        AS R			      ;average over power spectra of small
        pwa***                        ;pieces
        1-144
        A
        _1
        _2
        WU			      ;CALCULATE THE SQUARE ROOT OF POWER 
        _1			      ;spectrum so it agrees with SPIDER
        <2>                           ;CONVENTION
        RE
        ;...............................................................

     '</PRE>'

SUBROUTINE:  DEFOCUS, DEFO001, DEFO003

CALLER:      UTIL1


