
VO MD   Vector Operation - angular doc. file from 'AP MD' output  VO MD
                                                              10/22/99

PURPOSE:  Convert output document file from the 'AP MD', 'AP RD', or 'AP RN' 
          operation to an angular document file containing three Eulerian angles.

SEE ALSO: VO EA    
          VO RA     
          AP MD

USAGE:    VO MD

          .ANGULAR DOCUMENT FILE NAME: REFANG
          [Enter the name of the reference angles document file (created 
          by 'VO EA') used to calculate reference projections required 
          for 'AP MD', etc.]

          .OUTPUT FROM AP MD/RD/RN DOCUMENT: APMD101
          [Enter the name of the document file produced by the 'AP MD' 
          command.   This document file should contain 6 columns:
          '<pre>'
          1.Number of the most      2.Distance.             3. "-psi" angle
          similar reference         Can be used as          In-plane rotation
          projection.  When         a similarity measure.   angle determined.  
          this number is negative   Output from 
          the most similar is       AP MD document.
          a mirrored projection
          (see appended batch program).
          When this number is zero,
          the line is skipped and
          the output angular document
          file will not contain
          correspoding key.


          4. Always 0.0             5. Always 0.0            6.  Experimental
                                                             projection number.
          '</pre>'

          .DOCUMENT: OUTANGLES
          [Enter the name for the angular document file that will 
          be produced. This document file will contain three 
          columns with the three Eulerian angles psi, theta, and phi.
          The key numbers will correspond to experimental projection
          numbers from column 6 of the AP MD/RD/RN output document file.
          Thus, for image file series with gaps the keys will not be
          consecutive.  Moreover, for the output files from AP RD/RN
          operations the entries for non-matching projections (marked
          by 0 in the first column) will be omitted.
          The angular document file can be subsequently used in  
          the 'BP RP' operation to calculate a refined 3D reconstruction.]


NOTES: 1. In 3D space the projection with the direction (psi, theta, phi)
          has its mirrored [around X-axis] counterpart in the direction:'<BR>'
             (-psi, 180-theta, phi+180).'<BR>'
          To save time, the operation AP MD takes this into account, and 
          each data projection is compared with the reference projection and 
          its mirrored version at the same time.  Thus, only half of the total 
          number of reference projections are required, namely, only those
          with 0<theta<90.
          If the best match was with the mirrored reference projection,
          then the number stored in the first column of the document file
          is equal to the number of the corresponding mirrored reference
          projection plus an offset equal to the total number of reference 
          projections (see appended batch program).
  
       2. Implemented by P. Penczek

SUBROUTINE: VOMD

CALLER:     DRIV1

The command 'VO MD' is equivalent to the following SPIDER procedure:
'<pre>'
;  Prepare ang doc file after the alignment of projections
;
;  APMD101   - Input document file produced by 'AP MD' operation
;  REFANG    - Input document file with 2D reference projections angles 
;              stored in the order (psi, theta, phi)
;  OUTANGLES - Output ang document file to be used for 3D reconstruction

UD N,x88                    ; Find number of images
APMD101

DO LB1 x19=1,x88            ; Loop over all images
   UD IC,x19,x51,x52,x41,x61,x61,x81
   APMD101

   x41=-x41                 ; - the inplane rotation

   IF(x51.EQ.0) GOTO LB1    ; Skip images with no angles determined

   x61=x51
   IF(x51.LT.0)  x61=-x51   ; Index for non-mirrored image

   UD IC,x61,x22,x42,x43    ; Reference angles for this image
   REFANG

   IF(x51.LT.0) THEN        ; Adjust mirrored angles
      x41=x41+180.0         ; Add 180 to inplane rotation
      x42=180.0-x42         ; Adjust theta
      x43=x43+180.0         ; Adjust phi
   ENDIF

   SD x81,x41,x42,x43       ; Save adjusted angles
   OUTANGLES
LB1
EN
'</pre>'
